gchecky.model.calculate_t

Package gchecky :: Module model :: Class calculate_t |
[hide private]
[frames] | no frames]

# Class calculate_t

source code

    object --+
             |
     gxml.Node --+
                 |
                calculate_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| addresses = `List:PATH(addresses):OP`...``
| merchant_code_strings = `Node:PATH(merchant-code-strings/mercha`...``
| shipping = `Node:PATH(shipping):OPT:{ shipping_in_calculate_t }`
| tax = `gxml.Boolean('tax')`
| _fields = ``{``'``addresses``'``:` List:PATH(addresses):OP`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### addresses Value:
      List:PATH(addresses):OPT:[
          Node:PATH(anonymous-address):REQ:{ anonymous_address_t }
      ]

  ### merchant_code_strings Value:
      Node:PATH(merchant-code-strings/merchant-code-string):OPT:{ merchant_c
      ode_string_t }

  ### _fields list of meta-Fields of this class. Value:
      {'addresses': List:PATH(addresses):OPT:[
          Node:PATH(anonymous-address):REQ:{ anonymous_address_t }
      ],
       'merchant_code_strings': Node:PATH(merchant-code-strings/merchant-cod
      e-string):OPT:{ merchant_code_string_t },
       'shipping': Node:PATH(shipping):OPT:{ shipping_in_calculate_t },
       'tax': ??}